@@ -1,7 +1,7 @@
 # LearnRL a python library to learn and use reinforcement learning
 # Copyright (C) 2020 Mathïs FEDERICO <https://www.gnu.org/licenses/>
 
-from learnrl.environments.single_agents import RdNimEnv, RdCrossesAndNoughtsEnv
+from learnrl.environments.single_agents import RdNimEnv, CatchEnv
 from learnrl.environments.multi_agents import CrossesAndNoughtsEnv
 
 # Import basic gym envs
