@@ -1,5 +1,5 @@
 # LearnRL a python library to learn and use reinforcement learning
 # Copyright (C) 2020 Mathïs FEDERICO <https://www.gnu.org/licenses/>
 
-from learnrl.environments.single_agents.random_crosses_and_noughts import RdCrossesAndNoughtsEnv
 from learnrl.environments.single_agents.random_nim import RdNimEnv
+from learnrl.environments.single_agents.catch import CatchEnv
